define((function () { 'use strict';

	function foo() { return 'foo'; }

	assert.equal( foo(), 'foo' );

}));
